@@ -5,10 +5,10 @@ use cnetworks::*;
 fn test_get() {
     let net = Network::new(3, Model::None, Weight::default());
     for i in 0..3 {
-        assert!(net.get(i).is_ok());
+        assert!(net.contains(i));
     }
     for i in 3..100 {
-        assert_eq!(net.get(i).unwrap_err(), cn::Err::NoSuchNode(i));
+        assert!(!net.contains(i));
     }
 }
 
@@ -18,17 +18,22 @@ fn test_degs() {
     net.link(0, 1).unwrap();
     net.link(0, 2).unwrap();
 
-    assert_eq!(net[0].deg(), &2);
+    assert_eq!(net.deg_of(0).unwrap(), 2);
     assert_eq!(
-        net[0].links(),
-        &vec![(1, 1.0), (2, 1.0)].into_iter().collect()
+        net.links_of(0).unwrap(),
+        &vec![(1, 1.0), (2, 1.0)]
+            .into_iter()
+            .collect::<cn::IndexMap<_, _>>()
     );
 
-    assert_eq!(net[1].deg(), &1);
-    assert_eq!(net[1].links(), &vec![(0, 1.0)].into_iter().collect());
+    assert_eq!(net.deg_of(1).unwrap(), 1);
+    assert_eq!(
+        net.links_of(1).unwrap(),
+        &vec![(0, 1.0)].into_iter().collect::<cn::IndexMap<_, _>>()
+    );
 
-    assert_eq!(net[2].deg(), &1);
-    assert_eq!(net.total_deg(), 4);
+    assert_eq!(net.deg_of(2).unwrap(), 1);
+    assert_eq!(net.deg_total(), 4);
     assert_eq!(net.edges(), 2);
 
     assert_eq!(net.deg_distr(), vec![(1, 2), (2, 1)].into_iter().collect());
