@@ -7,21 +7,21 @@ fn test_spread_random() {
     net.link(0, 1).unwrap();
     net.link(1, 2).unwrap();
     net.link(2, 3).unwrap();
-    let (root, observers) = si::spread_random(&net, 1);
+    let observers = si::spread_random(&net, 1);
     let mut infected = observers.as_map().keys().copied().collect::<Vec<usize>>();
     infected.sort_unstable();
-    match root {
+    match observers.true_source() {
         0 => assert_eq!(infected, vec![1]),
         1 => assert_eq!(infected, vec![0, 2]),
         2 => assert_eq!(infected, vec![1, 3]),
         3 => assert_eq!(infected, vec![2]),
-        _ => panic!("Root should not be {}", root),
+        _ => panic!("Root should not be {}", observers.true_source()),
     }
-    let (root, observers) = si::spread_random(&net, 3);
-    assert!(vec![0, 1, 2, 3].contains(&root));
+    let observers = si::spread_random(&net, 3);
+    assert!(vec![0, 1, 2, 3].contains(&observers.true_source()));
     let mut infected = observers.as_map().keys().copied().collect::<Vec<usize>>();
     infected.sort_unstable();
     let mut cmp = vec![0, 1, 2, 3];
-    cmp.retain(|x| *x != root);
+    cmp.retain(|x| *x != observers.true_source());
     assert_eq!(infected, cmp)
 }
